@@ -20,8 +20,14 @@
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
 
-#include "common.h"
+#include <qchar.h>     // for QChar, operator==
+#include <qlist.h>     // for QList<>::const_iterator
+
+#include <utility>
+
+#include "common.h"    // for STABLE, NOTARCH, NOTAVAILABLE, HARDMASKED, TES...
 #include "packageversion.h"
+#include "settings.h"  // for KurooConfig
 
 /**
  * @class PackageVersion
@@ -31,41 +37,34 @@
 * Protected so that only PortagePackage can construct
 * a PackageVersion object.
 */
-PackageVersion::PackageVersion( const QString& version )
-	: m_version( version ), m_installed( false ), m_overlay( false ), m_isHardMasked( false ),
+PackageVersion::PackageVersion( QString  version )
+	: m_version(std::move( version )), m_installed( false ), m_overlay( false ), m_isHardMasked( false ),
 	// Regexp for a simple number, for use as a version number part
-	rxNumber("\\d+"),
+	rxNumber(QStringLiteral("\\d+")),
 	// Regexp for a revision number, which are everywhere
-	rxRevision("-r(\\d+)$"),
+	rxRevision(QStringLiteral("-r(\\d+)$")),
 	// Regexp for a version suffix, like in freetts-1.2_beta
-	rxSuffix("_(alpha|beta|pre|rc|p)(\\d*)(?:-r\\d+)?$"),
+	rxSuffix(QStringLiteral("_(alpha|beta|pre|rc|p)(\\d*)(?:-r\\d+)?$")),
 	// Regexp for a trailing character, like in util-linux-2.12i
-	rxTrailingChar("\\d([a-z])(?:_(?:alpha|beta|pre|rc|p)\\d*)?(?:-r\\d+)?$"),
+	rxTrailingChar(QStringLiteral("\\d([a-z])(?:_(?:alpha|beta|pre|rc|p)\\d*)?(?:-r\\d+)?$")),
 	m_isOriginalHardMasked( false ), m_isUserMasked( false ), m_isUnMasked( false )
 {
 }
 
-PackageVersion::~PackageVersion()
-{}
-
 /**
 * Returns true if this version is available (as in: can be installed) and false if not.
 * Use global ACCEPT_KEYWORDS in make.conf if set by user.
 */
-bool PackageVersion::isAvailable() const
+auto PackageVersion::isAvailable() const -> bool
 {
-	if ( KurooConfig::acceptKeywords().startsWith("~") )
-		return ( stability( "~" + KurooConfig::arch() ) == STABLE );
-	else
-		return ( stability( KurooConfig::arch() ) == STABLE );
+	if ( KurooConfig::acceptKeywords().startsWith(u'~') )
+		return ( stability( u'~' + KurooConfig::arch() ) == STABLE );
+	return ( stability( KurooConfig::arch() ) == STABLE );
 }
 
-bool PackageVersion::isNotArch() const
+auto PackageVersion::isNotArch() const -> bool
 {
-	if ( m_keywords.contains( KurooConfig::arch() ) || m_keywords.contains( "~" + KurooConfig::arch() ) )
-		return false;
-	else
-		return true;
+	return !(m_keywords.contains( KurooConfig::arch() ) || m_keywords.contains( u'~' + KurooConfig::arch() ));
 }
 
 /**
@@ -76,25 +75,25 @@ bool PackageVersion::isNotArch() const
 * @return  true if this version is newer than the one given in the argument.
 *          false if the other version is newer (or if the strings are equal).
 */
-bool PackageVersion::isNewerThan( const QString& otherVersion ) const
+auto PackageVersion::isNewerThan( const QString& otherVersion ) const -> bool
 {
 	// this* is for this->version, that* is for otherVersion
 	QString thisNum, thatNum;
 	
 	// Numerical representation of the suffix.
 	// Higher number means higher precedence.
-	long thisSuffix, thatSuffix;
+	long thisSuffix = 0, thatSuffix = 0;
 	
 	// Revision number. 0 means the version doesn't have a revision.
-	int thisRevision, thatRevision;
+	int thisRevision = 0, thatRevision = 0;
 	
 	// Numerical representation for possible trailing characters.
-	int thisTrailingChar, thatTrailingChar;
+	int thisTrailingChar = 0, thatTrailingChar = 0;
 	
-    int pos; // multi-purpose position integer
+    int pos = 0; // multi-purpose position integer
 	
 	// start index of revision, suffix, and trailing character
-	int revisionPos, suffixPos, trailingCharPos;
+	int revisionPos = 0, suffixPos = 0, trailingCharPos = 0;
 	
 	// Retrieve revision, suffix and their positions in the version string
 	thisRevision = PackageVersion::revisionNumber( m_version, &revisionPos );
@@ -141,18 +140,18 @@ bool PackageVersion::isNewerThan( const QString& otherVersion ) const
 	pos = 0; // pos is the start index for number searches
 	do {
         rxNumber.indexIn( m_version, pos );
-		thisNum = ( const_cast<PackageVersion*>(this) )->rxNumber.cap(0);
+		thisNum = rxNumber.cap(0);
         rxNumber.indexIn( otherVersion, pos );
-		thatNum = ( const_cast<PackageVersion*>(this) )->rxNumber.cap(0);
+		thatNum = rxNumber.cap(0);
 		
 		// Fix so '0.1.0 > 0.09.0' as '0.10.0 > 0.09.0'
 		if ( thisNum.length() > thatNum.length() ) {
-			if ( thisNum.startsWith( "0" ) )
-				thatNum = thatNum.leftJustified( thisNum.length(), '0' );
+			if ( thisNum.startsWith( u'0' ) )
+				thatNum = thatNum.leftJustified( thisNum.length(), u'0' );
 		}
 		else {
-			if ( thatNum.startsWith( "0" ) )
-				thisNum = thisNum.leftJustified( thatNum.length(), '0' );
+			if ( thatNum.startsWith( u'0' ) )
+				thisNum = thisNum.leftJustified( thatNum.length(), u'0' );
 		}
 		
 		if ( thisNum.isEmpty() || thatNum.isEmpty() )
@@ -160,50 +159,39 @@ bool PackageVersion::isNewerThan( const QString& otherVersion ) const
 		
 		// the current version number parts differ
 		if ( thisNum != thatNum ) {
-			if ( thisNum.toInt() > thatNum.toInt() ) // this->version is newer:
-				return true;
-				else // well, the otherVersion is newer.
-					return false;
+			return thisNum.toInt() > thatNum.toInt(); // this->version is newer:
 		}
-		else {
-			// thisNum == thatNum 
-			pos += thisNum.length();
-			
-			// check if any base-version string ends here
-			// both versions end here
-			if ( thisBaseVersion.length() <= pos && thatBaseVersion.length() <= pos ) {
-				// compare trailing characters, if they are the same,
-				// then suffixes, if they are also the same, then revisions
-				if ( thisTrailingChar > thatTrailingChar )
+		// thisNum == thatNum 
+		pos += thisNum.length();
+		
+		// check if any base-version string ends here
+		// both versions end here
+		if ( thisBaseVersion.length() <= pos && thatBaseVersion.length() <= pos ) {
+			// compare trailing characters, if they are the same,
+			// then suffixes, if they are also the same, then revisions
+			if ( thisTrailingChar > thatTrailingChar )
+				return true;
+			if ( thisTrailingChar < thatTrailingChar )
+				return false;
+			if ( thisTrailingChar == thatTrailingChar ) {
+				if ( thisSuffix > thatSuffix )
 					return true;
-				else if ( thisTrailingChar < thatTrailingChar )
+				if ( thisSuffix < thatSuffix )
 					return false;
-				else if ( thisTrailingChar == thatTrailingChar ) {
-					if ( thisSuffix > thatSuffix )
-						return true;
-					else if ( thisSuffix < thatSuffix )
-						return false;
-					else if ( thisSuffix == thatSuffix ) {
-						if ( thisRevision > thatRevision )
-							return true;
-						else // if( thisRevision <= thatRevision )
-							return false;
-					}
+				if ( thisSuffix == thatSuffix ) {
+					return thisRevision > thatRevision;
 				}
 			}
-			else
-				if ( thisBaseVersion.length() <= pos ) { // but not the other one
-					return false; // because the other version continues, like ".1"
-				}
-			else
-				if ( thatBaseVersion.length() <= pos ) { // but not this one
-					return true; // because this version continues, like ".1"
-				}
-			// so, both strings are not finished yet? then, go on...
-			else {
-				pos++; // skip the "." (to the start of the next number part)
-				continue;
-			}
+		}
+		else if ( thisBaseVersion.length() <= pos ) { // but not the other one
+			return false; // because the other version continues, like ".1"
+		} else if ( thatBaseVersion.length() <= pos ) { // but not this one
+			return true; // because this version continues, like ".1"
+		}
+		// so, both strings are not finished yet? then, go on...
+		else {
+			pos++; // skip the "." (to the start of the next number part)
+			continue;
 		}
 	}
 	while ( true );
@@ -222,12 +210,9 @@ bool PackageVersion::isNewerThan( const QString& otherVersion ) const
  * @return  true if this version is older than the one given in the argument.
  *          false if the other version is older (or if the strings are equal).
  */
-bool PackageVersion::isOlderThan( const QString& otherVersion ) const
+auto PackageVersion::isOlderThan( const QString& otherVersion ) const -> bool
 {
-	if ( m_version == otherVersion || isNewerThan( otherVersion ) == true )
-		return false;
-	else
-		return true;
+	return !(m_version == otherVersion || isNewerThan( otherVersion ));
 }
 
 /**
@@ -238,69 +223,61 @@ bool PackageVersion::isOlderThan( const QString& otherVersion ) const
 * @param arch  The architecture that the stability should be checked for
 *              (e.g. "x86" or "~alpha").
 */
-int PackageVersion::stability( const QString& arch ) const
+auto PackageVersion::stability( const QString& arch ) const -> int
 {
-	if ( m_isHardMasked == true )
+	if ( m_isHardMasked )
 		return HARDMASKED;
 	
 	// check for additional keywords
 	if ( !m_acceptedKeywords.empty() ) {
 		QString pureArch( arch );
-		pureArch.remove( '~' );
+		pureArch.remove( u'~' );
 		
 		// The following checks are not completely correct, as they only check
 		// against arch instead of all version keywords. Should be sufficient
 		// for normal use though, as people are not supposed to add anything
 		// but ~arch or -arch to ACCEPT_KEYWORDS/package.keywords.
-		for ( QStringList::const_iterator keywordIterator = m_acceptedKeywords.begin(); keywordIterator != m_acceptedKeywords.end(); keywordIterator++ ) {
+		for (const auto & m_acceptedKeyword : m_acceptedKeywords) {
 			
 			// Accept masked and stable packages
 			// when the accepted keyword is ~arch or ~*
-			if ( ( *keywordIterator == "~*" || *keywordIterator == "~" + arch ) && ( m_keywords.contains( "~" + pureArch ) || m_keywords.contains( pureArch ) ) ) {
+			if ( ( m_acceptedKeyword == QStringLiteral("~*") || m_acceptedKeyword == u'~' + arch ) && ( m_keywords.contains( u'~' + pureArch ) || m_keywords.contains( pureArch ) ) ) {
 				return STABLE;
 			}
 			// Accept packages when the accepted keyword is -arch and keywords contain -arch!
-			else
-                if( (*keywordIterator == "-" + arch && m_keywords.contains( "-" + arch ) ) || ( *keywordIterator == "-*" && m_keywords.contains("-*") ) ) {
-					return STABLE;
-				}
-				// Don't accept packages when the accepted keyword is -arch only
-				else
-					if ( *keywordIterator == "-" + arch && m_keywords.contains( arch ) ) {
-						return NOTAVAILABLE;
-					}
-					// Accept stable packages for an accepted keyword named "*"
-					else
-						if ( *keywordIterator == "*" && m_keywords.contains( pureArch ) ) {
-							return STABLE;
-						}
-						// Don't accept anything if it's got -* in it
-						else
-							if ( *keywordIterator == "-*" ) {
-								return NOTARCH;
-							}
+			if( (m_acceptedKeyword == u'-' + arch && m_keywords.contains( u'-' + arch ) ) || ( m_acceptedKeyword == QStringLiteral("-*") && m_keywords.contains(QStringLiteral("-*")) ) ) {
+				return STABLE;
 			}
+			// Don't accept packages when the accepted keyword is -arch only
+			if ( m_acceptedKeyword == QStringLiteral("-") + arch && m_keywords.contains( arch ) ) {
+				return NOTAVAILABLE;
+			}
+			// Accept stable packages for an accepted keyword named "*"
+			if ( m_acceptedKeyword == u'*' && m_keywords.contains( pureArch ) ) {
+				return STABLE;
+			}
+			// Don't accept anything if it's got -* in it
+			if ( m_acceptedKeyword == QStringLiteral("-*") ) {
+				return NOTARCH;
+			}
+		}
 	}
 	
 	// check if the architecture is in there "as is"
 	if ( m_keywords.contains( arch ) )
 		return STABLE;
 	// check if there is a masked version of the architecture in there
-	else
-		if ( m_keywords.contains( "~" + arch ) )
-			return TESTING;
-		// if arch is masked, check if a stable version is in there
-		else
-			if ( arch.count() > 0 && (arch[0] == QChar('~') ) && ( m_keywords.contains( arch.mid(1) ) ) )
-				return STABLE;
-			// well, no such arch in the version info
-			else
-				if ( m_keywords.contains( "-*") || m_keywords.contains( "-" + arch ) ) {
-					// which is also "-*"
-					return NOTAVAILABLE;
-				}
-				else
-					return NOTARCH;
+	if ( m_keywords.contains( u'~' + arch ) )
+		return TESTING;
+	// if arch is masked, check if a stable version is in there
+	if ( arch.length() > 0 && (arch[0] == u'~' ) && ( m_keywords.contains( arch.mid(1) ) ) )
+		return STABLE;
+	// well, no such arch in the version info
+	if ( m_keywords.contains(QStringLiteral("-*")) || m_keywords.contains( QStringLiteral("-") + arch ) ) {
+		// which is also "-*"
+		return NOTAVAILABLE;
+	}
+	return NOTARCH;
 }
 
 
@@ -316,23 +293,22 @@ int PackageVersion::stability( const QString& arch ) const
 * @returns  The revision number (NUM out of "-rNUM"),
 *           or 0 if no revision has been found.
 */
-int PackageVersion::revisionNumber( const QString& versionString, int* foundPos ) const
+auto PackageVersion::revisionNumber( const QString& versionString, int* foundPos ) const -> int
 {
 	// search for a possible revision
     int pos = rxRevision.indexIn( versionString );
 	
 	// return the position inside the string
-	if ( foundPos != NULL )
+	if ( foundPos != nullptr )
 		*foundPos = pos;
 	
 	// no revision, which is essentially the same as -r0
 	if ( pos == -1 ) {
 		return 0;
 	}
-	else {
- 		// has a revision, get its number
-		return ( const_cast<PackageVersion*>(this) )->rxRevision.cap(1).toInt();
-	}
+	// has a revision, get its number
+	return rxRevision.cap(1).toInt();
+
 } // end of revisionNumber()
 
 /**
@@ -350,40 +326,39 @@ int PackageVersion::revisionNumber( const QString& versionString, int* foundPos
 *           (that's only "_p") get numbers above 0. Overall, a higher number
 *           means higher precedence.
 */
-long PackageVersion::suffixNumber( const QString& versionString, int* foundPos ) const
+auto PackageVersion::suffixNumber( const QString& versionString, int* foundPos ) const -> long
 {
 	// search for a possible suffix
     int pos = rxSuffix.indexIn( versionString );
 	
-	if ( foundPos != NULL ) // return the position inside the string
+	if ( foundPos != nullptr ) // return the position inside the string
 		*foundPos = pos;
 	
 	if ( pos == -1 ) { // no suffix, which means no change in importance
 		return 0;
 	}
-	else // there is a suffix, check which one
-	{
-		// the regexps have to be casted to normal, because the const
-		// method signature makes them const too (which is not wanted)
-		QString suffix = (const_cast<PackageVersion*>(this))->rxSuffix.cap(1);
-		int suffixNumber = (const_cast<PackageVersion*>(this))->rxSuffix.cap(2).toInt(); // X in, say "_betaX"
-		// if it's just "_beta" (which is allowed), toInt("") returns 0.
-		
-		// The big numbers are needed because some people use stuff like
-		// _p20041130 which is more than an integer can handle
-		if ( suffix == "alpha" ) // alpha release
-			return -400000000 + suffixNumber;
-		else if ( suffix == "beta" ) // beta release
-			return -300000000 + suffixNumber;
-		else if ( suffix == "pre" ) // prerelease
-			return -200000000 + suffixNumber;
-		else if ( suffix == "rc" ) // release candidate
-			return -100000000 + suffixNumber;
-		else if ( suffix == "p" ) // patch level. better than a normal release.
-			return 100000000 + suffixNumber;
-		else // should not happen, but anyways
-			return 0;
-	}
+	// there is a suffix, check which one
+	// the regexps have to be casted to normal, because the const
+	// method signature makes them const too (which is not wanted)
+	QString suffix = rxSuffix.cap(1);
+	int suffixNumber = rxSuffix.cap(2).toInt(); // X in, say "_betaX"
+	// if it's just "_beta" (which is allowed), toInt("") returns 0.
+	
+	// The big numbers are needed because some people use stuff like
+	// _p20041130 which is more than an integer can handle
+	if ( suffix == QStringLiteral("alpha") ) // alpha release
+		return -400000000 + suffixNumber;
+	if ( suffix == QStringLiteral("beta") ) // beta release
+		return -300000000 + suffixNumber;
+	if ( suffix == QStringLiteral("pre") ) // prerelease
+		return -200000000 + suffixNumber;
+	if ( suffix == QStringLiteral("rc") ) // release candidate
+		return -100000000 + suffixNumber;
+	if ( suffix == QStringLiteral("p") ) // patch level. better than a normal release.
+		return 100000000 + suffixNumber;
+	// should not happen, but anyways
+	return 0;
+
 } // end of suffixNumber()
 
 /**
@@ -398,7 +373,7 @@ long PackageVersion::suffixNumber( const QString& versionString, int* foundPos )
 * @returns  A numerical representation of the character (1 or more).
 *           or 0 if no revision has been found.
 */
-int PackageVersion::trailingCharNumber( const QString& versionString, int* foundPos ) const
+auto PackageVersion::trailingCharNumber( const QString& versionString, int* foundPos ) const -> int
 {
 	// search for a possible trailing character
     int pos = rxTrailingChar.indexIn( versionString );
@@ -406,13 +381,13 @@ int PackageVersion::trailingCharNumber( const QString& versionString, int* found
 		pos++; // because the regexp starts one character left
 	// of the actual position
 	
-	if ( foundPos != NULL ) // return the position inside the string
+	if ( foundPos != nullptr ) // return the position inside the string
 		*foundPos = pos;
 	
 	if ( pos == -1 ) // no trailing character, so return 0
 		return 0;
-	else // has a trailing character, get its number
-		return (int) versionString.at(pos).toLatin1();
+	// has a trailing character, get its number
+	return static_cast<int>(versionString.at(pos).toLatin1());
 }
 
 
@@ -423,7 +398,7 @@ int PackageVersion::trailingCharNumber( const QString& versionString, int* found
 /**
  * Returns the package version string.
  */
-const QString& PackageVersion::version() const
+auto PackageVersion::version() const -> const QString&
 {
 	return m_version;
 }
@@ -441,7 +416,7 @@ void PackageVersion::setVersion( const QString& version )
 * Returns the package description.
 * @see setDescription
 */
-const QString& PackageVersion::description() const
+auto PackageVersion::description() const -> const QString&
 {
 	return m_description;
 }
@@ -459,7 +434,7 @@ void PackageVersion::setDescription( const QString& description )
 * Returns true if this package version is installed, false if not.
 * @see setInstalled
 */
-bool PackageVersion::isInstalled() const
+auto PackageVersion::isInstalled() const -> bool
 {
 	return m_installed;
 }
@@ -479,7 +454,7 @@ void PackageVersion::setInstalled( bool isInstalled )
 * false if it's in the mainline Portage tree.
 * @see setOverlay
 */
-bool PackageVersion::isOverlay() const
+auto PackageVersion::isOverlay() const -> bool
 {
 	return m_overlay;
 }
@@ -498,7 +473,7 @@ void PackageVersion::setOverlay( bool isOverlay )
 * Get the ebuild's last modification time.
 * @see setDate
 */
-const QString& PackageVersion::date() const
+auto PackageVersion::date() const -> const QString&
 {
 	return m_date;
 }
@@ -516,7 +491,7 @@ void PackageVersion::setDate( const QString& date )
 * Get the home page of this package version.
 * @see setHomepage
 */
-const QString& PackageVersion::homepage() const
+auto PackageVersion::homepage() const -> const QString&
 {
 	return m_homepage;
 }
@@ -534,7 +509,7 @@ void PackageVersion::setHomepage( const QString& homepage )
 * Get the slot that this package is in.
 * @see setSlot
 */
-const QString& PackageVersion::slot() const
+auto PackageVersion::slot() const -> const QString&
 {
 	return m_slot;
 }
@@ -551,7 +526,7 @@ void PackageVersion::setSlot( const QString& slot )
 /**
 * Get the licenses used for this package.
 */
-const QStringList& PackageVersion::licenses() const
+auto PackageVersion::licenses() const -> const QStringList&
 {
 	return m_licenses;
 }
@@ -567,7 +542,7 @@ void PackageVersion::setLicenses( const QStringList& licenses )
 /**
 * Get the keywords of this package.
 */
-const QStringList& PackageVersion::keywords() const
+auto PackageVersion::keywords() const -> const QStringList&
 {
 	return m_keywords;
 }
@@ -583,7 +558,7 @@ void PackageVersion::setKeywords( const QStringList& keywords )
 /**
 * Get the USE flags that this package can use.
 */
-const QStringList& PackageVersion::useflags() const
+auto PackageVersion::useflags() const -> const QStringList&
 {
 	return m_useflags;
 }
@@ -602,10 +577,10 @@ void PackageVersion::setUseflags( const QStringList& useflags )
 * part of this list (which may be, for example, x86, ~amd64 and ~ia64)
 * then the ebuild is stable and can be installed.
 */
-QStringList& PackageVersion::acceptedKeywords()
-{
-	return m_acceptedKeywords;
-}
+//QStringList& PackageVersion::acceptedKeywords()
+//{
+//	return m_acceptedKeywords;
+//}
 
 /**
 * Set the list of accepted keywords marked for this package.
@@ -620,7 +595,7 @@ void PackageVersion::setAcceptedKeywords( const QStringList& keywords )
 * For Portage, this is the size of the files that have to be downloaded,
 * the hard disk space of the resulting compilation can not be predicted.
 */
-QString PackageVersion::size() const
+auto PackageVersion::size() const -> QString
 {
 	return m_size;
 }
@@ -636,32 +611,29 @@ void PackageVersion::setSize( const QString& size )
 /**
 * Returns true if this version is marked as hard masked, false if not.
 */
-bool PackageVersion::isHardMasked() const
+auto PackageVersion::isHardMasked() const -> bool
 {
 	return m_isHardMasked;
 }
 
-bool PackageVersion::isUserMasked() const
+auto PackageVersion::isUserMasked() const -> bool
 {
 	return m_isUserMasked;
 }
 
-bool PackageVersion::isUnMasked() const
+auto PackageVersion::isUnMasked() const -> bool
 {
 	return m_isUnMasked;
 }
 
-bool PackageVersion::isOriginalHardMasked() const
+auto PackageVersion::isOriginalHardMasked() const -> bool
 {
 	return m_isOriginalHardMasked;
 }
 
-bool PackageVersion::isOriginalTesting() const
+auto PackageVersion::isOriginalTesting() const -> bool
 {
-	if ( m_keywords.contains( "~" + KurooConfig::arch() ) )
-		return true;
-	else
-		return false;
+	return m_keywords.contains( u'~' + KurooConfig::arch() );
 }
 
 /**
