@@ -18,58 +18,87 @@
 *	59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.				*
 ***************************************************************************/
 
-#include <unistd.h>
-#include <QTextStream>
-#include <ThreadWeaver/Job>
-#include <ThreadWeaver/JobPointer>
-#include <ThreadWeaver/QObjectDecorator>
-#include <ThreadWeaver/Queue>
-#include <ThreadWeaver/Thread>
+#include <KAuth/Action>                    // for Action
+#include <KAuth/ExecuteJob>                // for ExecuteJob
+#include <qdatetime.h>                      // for QDateTime
+#include <qdebug.h>                         // for QDebug
+#include <qfile.h>                          // for QFile
+#include <qglobal.h>                        // for qWarning, foreach, qCritical
+#include <qiodevice.h>                      // for QIODevice, QIODevice::Rea...
+#include <qlist.h>                          // for QList
+#include <qmap.h>                           // for QMap
+#include <qobject.h>                        // for QObject
+#include <qobjectdefs.h>                    // for emit
+#include <qstring.h>                        // for QString, operator+, opera...
+#include <qstringlist.h>                    // for QStringList
+#include <qtextstream.h>                    // for QTextStream
+#include <threadweaver/job.h>               // for Job
+#include <threadweaver/jobinterface.h>      // for JobPointer
+#include <threadweaver/qobjectdecorator.h>  // for QObjectDecorator
+#include <threadweaver/queue.h>             // for Queue
+#include <threadweaver/queuestream.h>       // for QueueStream
+#include <unistd.h>                         // for usleep
 
-#include "common.h"
-#include "scanportagejob.h"
-#include "cacheportagejob.h"
-#include "scanupdatesjob.h"
+#include <utility>
 
+#include "cacheportagejob.h"                // for CachePortageJob
+#include "common.h"                         // for KurooDBSingleton, Signali...
+#include "emerge.h"                         // for Emerge
+#include "global.h"                         // for parsePackage
+#include "portage.h"                        // for Portage
+#include "portage/portage.h"
+#include "portagedb.h"                      // for KurooDB, DbConnection (pt...
+#include "portagefiles.h"                   // for PortageFiles
+#include "queue.h"                          // for Queue
+#include "scanportagejob.h"                 // for ScanPortageJob
+#include "scanupdatesjob.h"                 // for ScanUpdatesJob
+#include "settings.h"                       // for KurooConfig
+#include "signalist.h"                      // for Signalist
+
+namespace ThreadWeaver {
+class Thread;
+}  // namespace ThreadWeaver
+
+// TODO: these really need to be in their own files, then the include portage.moc at the bottom shouldn't be needed
 class AddInstalledPackageJobImpl : public ThreadWeaver::Job
 {
 public:
-	AddInstalledPackageJobImpl( const QString& package ) : ThreadWeaver::Job(), m_package( package ) {}
+	explicit AddInstalledPackageJobImpl( QString  package ) :  m_package(std::move( package )) {}
 
-	virtual void run( ThreadWeaver::JobPointer, ThreadWeaver::Thread* ) {
+	void run( ThreadWeaver::JobPointer /*self*/, ThreadWeaver::Thread*  /*thread*/) override {
 
 		QStringList parts = parsePackage( m_package );
 		if ( parts.isEmpty() ) {
-			qWarning() << QString("Inserting emerged package: can not match %1.").arg( m_package );
+			qWarning() << QStringLiteral("Inserting emerged package: can not match %1.").arg( m_package );
 			return;
 		}
 		QString category = parts[0];
 		QString name = parts[1];
-		QString version = parts[2];
+		QString version = parts[2] % u'-' % parts[3];
 
 		DbConnection* const m_db = KurooDBSingleton::Instance()->getStaticDbConnection();
-		QString id = KurooDBSingleton::Instance()->singleQuery( QString( "SELECT id FROM package WHERE "
-			"name = '%1' AND category = '%2' LIMIT 1;").arg( name ).arg( category ), m_db );
+		QString id = KurooDBSingleton::Instance()->singleQuery( QStringLiteral( "SELECT id FROM package WHERE "
+			"name = '%1' AND category = '%2' LIMIT 1;").arg( name, category ), m_db );
 
 		if ( id.isEmpty() ) {
 
-			qWarning() << QString("Inserting emerged package: Can not find id in database for package %1/%2.")
-				.arg( category ).arg( name );
+			qWarning() << QStringLiteral("Inserting emerged package: Can not find id in database for package %1/%2.")
+				.arg( category, name );
 
 			KurooDBSingleton::Instance()->returnStaticDbConnection( m_db );
 //			return;
 		}
 		else {
-			KurooDBSingleton::Instance()->query( QString( "UPDATE package SET status = '%1' WHERE id = '%2';" )
-												.arg( PACKAGE_INSTALLED_STRING ).arg( id ), m_db );
+			KurooDBSingleton::Instance()->query( QStringLiteral( "UPDATE package SET status = '%1' WHERE id = '%2';" )
+												.arg( PACKAGE_INSTALLED_STRING, id ), m_db );
 
-			KurooDBSingleton::Instance()->query( QString( "UPDATE version SET status = '%1' WHERE idPackage = '%2' AND name = '%3';" )
-												.arg( PACKAGE_INSTALLED_STRING ).arg( id ).arg( version ), m_db );
+			KurooDBSingleton::Instance()->query( QStringLiteral( "UPDATE version SET status = '%1' WHERE idPackage = '%2' AND name = '%3';" )
+												.arg( PACKAGE_INSTALLED_STRING, id, version ), m_db );
 
 			// Clean out the update string if this version was installed
-			KurooDBSingleton::Instance()->query( QString( "UPDATE package SET updateVersion = '' "
+			KurooDBSingleton::Instance()->query( QStringLiteral( "UPDATE package SET updateVersion = '' "
 														"WHERE id = '%1' AND ( updateVersion = '%2' OR updateVersion = '%3' );" )
-												.arg( id ).arg( version + " (D)" ).arg( version + " (U)" ), m_db );
+												.arg( id, version + QStringLiteral(" (D)"), version + QStringLiteral(" (U)") ), m_db );
 
 			KurooDBSingleton::Instance()->returnStaticDbConnection( m_db );
 //			return;
@@ -82,6 +111,7 @@ public:
 
 private:
 	const QString m_package;
+	Q_DISABLE_COPY(AddInstalledPackageJobImpl)
 };
 /**
 * @class AddInstalledPackageJob
@@ -89,34 +119,35 @@ private:
 */
 class AddInstalledPackageJob : public ThreadWeaver::QObjectDecorator
 {
+	Q_OBJECT
 public:
-	AddInstalledPackageJob( const QString& package )
+	explicit AddInstalledPackageJob( const QString& package )
 	: ThreadWeaver::QObjectDecorator( new AddInstalledPackageJobImpl( package ) ) {}
 };
 
 class RemoveInstalledPackageJobImpl : public ThreadWeaver::Job
 {
 public:
-	RemoveInstalledPackageJobImpl( const QString& package ) : ThreadWeaver::Job(), m_package( package ) {}
+	explicit RemoveInstalledPackageJobImpl( QString  package ) :  m_package(std::move( package )) {}
 
-	virtual void run( ThreadWeaver::JobPointer, ThreadWeaver::Thread* ) {
+	void run( ThreadWeaver::JobPointer /*self*/, ThreadWeaver::Thread*  /*thread*/) override {
 		QStringList parts = parsePackage( m_package );
 		if ( parts.isEmpty() ) {
-			qWarning() << QString("Removing unmerged package: can not match %1.").arg( m_package );
+			qWarning() << QStringLiteral("Removing unmerged package: can not match %1.").arg( m_package );
 			return;
 		}
 		QString category = parts[0];
 		QString name = parts[1];
-		QString version = parts[2];
+		QString version = parts[2] % u'-' % parts[3];
 
 		DbConnection* const m_db = KurooDBSingleton::Instance()->getStaticDbConnection();
 
-		QString id = KurooDBSingleton::Instance()->singleQuery( QString( "SELECT id FROM package WHERE "
-			"name = '%1' AND category = '%2' LIMIT 1;").arg( name ).arg( category ), m_db );
+		QString id = KurooDBSingleton::Instance()->singleQuery( QStringLiteral( "SELECT id FROM package WHERE "
+			"name = '%1' AND category = '%2' LIMIT 1;").arg( name, category ), m_db );
 
 		if ( id.isEmpty() ) {
-			qWarning() << QString("Removing unmerged package: Can not find id in database for package %1/%2.")
-				.arg( category ).arg( name );
+			qWarning() << QStringLiteral("Removing unmerged package: Can not find id in database for package %1/%2.")
+				.arg( category, name );
 
 			KurooDBSingleton::Instance()->returnStaticDbConnection( m_db );
 //			return;
@@ -125,24 +156,24 @@ public:
 
 			// Check how many version are installed
 			QString installedVersionCount = KurooDBSingleton::Instance()->singleQuery(
-				QString( "SELECT COUNT(id) FROM version WHERE idPackage = '%1' AND status = '%2' LIMIT 1;")
-				.arg( id ).arg( PACKAGE_INSTALLED_STRING ), m_db );
+				QStringLiteral( "SELECT COUNT(id) FROM version WHERE idPackage = '%1' AND status = '%2' LIMIT 1;")
+				.arg( id, PACKAGE_INSTALLED_STRING ), m_db );
 
 			// Mark package as uninstalled only when one version is found
-			if ( installedVersionCount == "1" ) {
+			if ( installedVersionCount == u'1' ) {
 
 				// Mark package as uninstalled
-				KurooDBSingleton::Instance()->singleQuery( QString( "UPDATE package SET status = '%1' WHERE id = '%2'")
-															.arg( PACKAGE_AVAILABLE_STRING ).arg( id ), m_db );
+				KurooDBSingleton::Instance()->singleQuery( QStringLiteral( "UPDATE package SET status = '%1' WHERE id = '%2'")
+															.arg( PACKAGE_AVAILABLE_STRING, id ), m_db );
 
 				// Delete package if "old" = not in official Portage anymore
-				KurooDBSingleton::Instance()->singleQuery( QString( "UPDATE package SET status = '%1' WHERE status = '%2' AND id = '%3';" )
-															.arg( PACKAGE_DELETED_STRING ).arg( PACKAGE_OLD_STRING ).arg( id ), m_db );
+				KurooDBSingleton::Instance()->singleQuery( QStringLiteral( "UPDATE package SET status = '%1' WHERE status = '%2' AND id = '%3';" )
+															.arg( PACKAGE_DELETED_STRING, PACKAGE_OLD_STRING, id ), m_db );
 			}
 
 			// And now mark this specific version as not installed
-			KurooDBSingleton::Instance()->singleQuery( QString( "UPDATE version SET status = '%1' WHERE idPackage = '%2' AND name = '%3';" )
-														.arg( PACKAGE_AVAILABLE_STRING ).arg( id ).arg( version ), m_db );
+			KurooDBSingleton::Instance()->singleQuery( QStringLiteral( "UPDATE version SET status = '%1' WHERE idPackage = '%2' AND name = '%3';" )
+														.arg( PACKAGE_AVAILABLE_STRING, id, version ), m_db );
 
 			KurooDBSingleton::Instance()->returnStaticDbConnection( m_db );
 //			return;
@@ -155,6 +186,7 @@ public:
 
 private:
 	const QString m_package;
+	Q_DISABLE_COPY(RemoveInstalledPackageJobImpl)
 };
 
 /**
@@ -163,34 +195,35 @@ private:
 */
 class RemoveInstalledPackageJob : public ThreadWeaver::QObjectDecorator
 {
+	Q_OBJECT
 public:
-	RemoveInstalledPackageJob( const QString& package )
+	explicit RemoveInstalledPackageJob( const QString& package )
 	: ThreadWeaver::QObjectDecorator( new RemoveInstalledPackageJobImpl( package ) ) {}
 };
 
 class CheckUpdatesPackageJobImpl : public ThreadWeaver::Job
 {
 public:
-	CheckUpdatesPackageJobImpl( const QString& id, const QString& updateVersion, int hasUpdate )
-	: ThreadWeaver::Job(),
-		m_id( id ), m_updateVersion( updateVersion ), m_hasUpdate( hasUpdate ) {}
+	CheckUpdatesPackageJobImpl( QString  id, QString  updateVersion, int hasUpdate )
+	: 
+		m_id(std::move( id )), m_updateVersion(std::move( updateVersion )), m_hasUpdate( hasUpdate ) {}
 
-	virtual void run( ThreadWeaver::JobPointer, ThreadWeaver::Thread* ) {
+	void run( ThreadWeaver::JobPointer /*self*/, ThreadWeaver::Thread*  /*thread*/) override {
 		DbConnection* const m_db = KurooDBSingleton::Instance()->getStaticDbConnection();
 
 		if ( m_hasUpdate == 0 ) {
-			KurooDBSingleton::Instance()->singleQuery( QString("UPDATE package SET updateVersion = '', status = '%1' WHERE id = '%2';")
-														.arg( PACKAGE_INSTALLED_STRING ).arg( m_id ), m_db );
+			KurooDBSingleton::Instance()->singleQuery( QStringLiteral("UPDATE package SET updateVersion = '', status = '%1' WHERE id = '%2';")
+														.arg( PACKAGE_INSTALLED_STRING, m_id ), m_db );
 		}
 		else {
 			QString updateString;
 			if ( m_hasUpdate > 0 )
-				updateString = m_updateVersion + " (U)";
+				updateString = m_updateVersion + QStringLiteral(" (U)");
 			else
-				updateString = m_updateVersion + " (D)";
+				updateString = m_updateVersion + QStringLiteral(" (D)");
 
-			KurooDBSingleton::Instance()->singleQuery( QString( "UPDATE package SET updateVersion = '%1', status = '%2' WHERE id = '%3';" )
-														.arg( updateString ).arg( PACKAGE_UPDATES_STRING ).arg( m_id ), m_db );
+			KurooDBSingleton::Instance()->singleQuery( QStringLiteral( "UPDATE package SET updateVersion = '%1', status = '%2' WHERE id = '%3';" )
+														.arg( updateString, PACKAGE_UPDATES_STRING, m_id ), m_db );
 		}
 
 		KurooDBSingleton::Instance()->returnStaticDbConnection( m_db );
@@ -204,6 +237,7 @@ public:
 private:
 	const 	QString m_id, m_updateVersion;
 	int 	m_hasUpdate;
+	Q_DISABLE_COPY(CheckUpdatesPackageJobImpl)
 };
 /**
 * @class CheckUpdatesPackageJob
@@ -211,6 +245,7 @@ private:
 */
 class CheckUpdatesPackageJob : public ThreadWeaver::QObjectDecorator
 {
+	Q_OBJECT
 public:
 	CheckUpdatesPackageJob( const QString& id, const QString& updateVersion, int hasUpdate )
 		: ThreadWeaver::QObjectDecorator( new CheckUpdatesPackageJobImpl( id, updateVersion, hasUpdate ) ) {}
@@ -231,19 +266,19 @@ Portage::Portage( QObject *m_parent )
 	: QObject( m_parent )
 {
 	// When cache scan is done go one scanning portage for all packages
-	connect( SignalistSingleton::Instance(), SIGNAL( signalCachePortageComplete() ), this, SLOT( slotScan() ) );
+	connect( SignalistSingleton::Instance(), &Signalist::signalCachePortageComplete, this, &Portage::slotScan );
 	// Then portage scan is completed
-	connect( SignalistSingleton::Instance(), SIGNAL( signalScanPortageComplete() ), this, SLOT( slotScanCompleted() ) );
+	connect( SignalistSingleton::Instance(), &Signalist::signalScanPortageComplete, this, &Portage::slotScanCompleted );
 
-	connect( SignalistSingleton::Instance(), SIGNAL( signalScanUpdatesComplete() ), this, SLOT( slotLoadUpdates() ) );
-	connect( SignalistSingleton::Instance(), SIGNAL( signalLoadUpdatesComplete() ), this, SLOT( slotChanged() ) );
+	connect( SignalistSingleton::Instance(), &Signalist::signalScanUpdatesComplete, this, &Portage::slotLoadUpdates );
+	connect( SignalistSingleton::Instance(), &Signalist::signalLoadUpdatesComplete, this, &Portage::slotChanged );
 
 	// Start refresh directly after emerge sync
-	connect( SignalistSingleton::Instance(), SIGNAL( signalSyncDone() ), this, SLOT( slotSyncCompleted() ) );
+	connect( SignalistSingleton::Instance(), &Signalist::signalSyncDone, this, &Portage::slotSyncCompleted );
 }
 
 Portage::~Portage()
-{}
+= default;
 
 void Portage::init( QObject *parent )
 {
@@ -257,9 +292,9 @@ void Portage::init( QObject *parent )
 void Portage::slotChanged()
 {
 	// Register in db so we can check at next start if user has emerged any packages outside kuroo
-	KurooDBSingleton::Instance()->setKurooDbMeta( "scanTimeStamp", QString::number( QDateTime::currentDateTime().toTime_t() ) );
+	KurooDBSingleton::Instance()->setKurooDbMeta( QStringLiteral("scanTimeStamp"), QString::number( QDateTime::currentSecsSinceEpoch() ) );
 
-	emit signalPortageChanged();
+	Q_EMIT signalPortageChanged();
 }
 
 /**
@@ -280,15 +315,15 @@ void Portage::slotPackageChanged()
 * Start scan of portage packages.
 * @return bool
 */
-bool Portage::slotRefresh()
+auto Portage::slotRefresh() -> bool
 {
 	DEBUG_LINE_INFO;
 	// Update cache if empty
 	if ( KurooDBSingleton::Instance()->isCacheEmpty() ) {
 		SignalistSingleton::Instance()->scanStarted();
 		//This seems important, not sure why it was commented out
-		CachePortageJob *job = new CachePortageJob();
-		connect(job, &CachePortageJob::done, this, &Portage::slotWeaverDone);
+		auto *job = new ThreadWeaver::QObjectDecorator( new CachePortageJob() );
+		connect(job, &ThreadWeaver::QObjectDecorator::done, this, &Portage::slotWeaverDone);
 		ThreadWeaver::Queue::instance()->stream() << job;
 	}
 	else
@@ -301,10 +336,9 @@ bool Portage::slotRefresh()
 * Start emerge sync.
 * @return bool
 */
-bool Portage::slotSync()
+void Portage::slotSync()
 {
 	EmergeSingleton::Instance()->sync();
-	return true;
 }
 
 /**
@@ -319,7 +353,7 @@ void Portage::slotSyncCompleted()
 * Continue with scan of portage packages.
 * @return bool
 */
-bool Portage::slotScan()
+auto Portage::slotScan() -> bool
 {
 	DEBUG_LINE_INFO;
 
@@ -337,8 +371,8 @@ bool Portage::slotScan()
 		}
 	}
 
-	ScanPortageJob *job = new ScanPortageJob();
-	connect(job, &ScanPortageJob::done, this, &Portage::slotWeaverDone);
+	auto *job = new ThreadWeaver::QObjectDecorator( new ScanPortageJob() );
+	connect(job, &ThreadWeaver::QObjectDecorator::done, this, &Portage::slotWeaverDone);
 	ThreadWeaver::Queue::instance()->stream() << job;
 
 	return true;
@@ -381,9 +415,9 @@ void Portage::loadWorld()
 		QTextStream stream( &file );
 		while ( !stream.atEnd() ) {
 			QString package = stream.readLine();
-			m_mapWorld[ package.trimmed() ] = QString::null;
+			m_mapWorld[ package.trimmed() ] = QString();
 		}
-		emit signalWorldChanged();
+		Q_EMIT signalWorldChanged();
 	}
 	else
 		qCritical() << "Loading packages in @world. Reading: " << KurooConfig::fileWorld();
@@ -394,7 +428,7 @@ void Portage::loadWorld()
 * @param package
 * @return true/false
 */
-bool Portage::isInWorld( const QString& package )
+auto Portage::isInWorld( const QString& package ) -> bool
 {
 	return m_mapWorld.contains( package );
 }
@@ -405,27 +439,11 @@ bool Portage::isInWorld( const QString& package )
 */
 void Portage::appendWorld( const QStringList& packageList )
 {
-	// Check is @world is writable
-	QFile file( KurooConfig::fileWorld() );
-	if ( !file.open( QIODevice::WriteOnly ) ) {
-		qCritical() << "Adding packages to @world. Writing: " << KurooConfig::fileWorld();
-		return;
-	}
-
-	// Make a copy of @world map
-	QMap<QString, QString> map = m_mapWorld;
-
 	// Add/update package into @world map
-	foreach ( QString pkg, packageList )
-		m_mapWorld.insert( pkg, QString::null );
+	for ( const QString& pkg : packageList )
+		m_mapWorld.insert( pkg, QString() );
 
-	// Update @world file
-	QTextStream stream( &file );
-	for ( QMap<QString, QString>::ConstIterator it = m_mapWorld.begin(), end = m_mapWorld.end(); it != end; ++it )
-		stream << it.key() << "\n";
-	file.close();
-
-	emit signalWorldChanged();
+	writeWorld();
 }
 
 /**
@@ -434,24 +452,28 @@ void Portage::appendWorld( const QStringList& packageList )
 */
 void Portage::removeFromWorld( const QStringList& packageList )
 {
-	// Check is @world is writable
-	QFile file( KurooConfig::fileWorld() );
-	if ( !file.open( QIODevice::WriteOnly ) ) {
-		qCritical() << "Removing packages from @world. Writing: " << KurooConfig::fileWorld();
-		return;
-	}
-
 	// Make a copy of @world map
-	foreach( QString pkg, packageList )
+	for( const QString& pkg : packageList )
 		m_mapWorld.remove( pkg );
+	
+	writeWorld();
+}
 
-	// Update @world file
-	QTextStream stream( &file );
-	for ( QMap<QString, QString>::ConstIterator it = m_mapWorld.begin(), end = m_mapWorld.end(); it != end; ++it )
-		stream << it.key() << "\n";
-	file.close();
-
-	emit signalWorldChanged();
+void Portage::writeWorld()
+{
+	KAuth::Action writeworld( QStringLiteral("org.gentoo.kuroo.writeworld") );
+	writeworld.setHelperId( QStringLiteral("org.gentoo.kuroo") );
+	//writeworld.setTimeout( 60*60*24*1000 );		// Should finish within default timeout
+	
+	writeworld.addArgument( QStringLiteral("worldfile"), KurooConfig::fileWorld() );
+	writeworld.addArgument( QStringLiteral("worldmap"), QStringList( m_mapWorld.keys() ) );
+	
+	KAuth::ExecuteJob *job = writeworld.execute();
+	if ( job->exec() ) {
+		Q_EMIT signalWorldChanged();
+	} else {
+		qCritical() << "Error writing world file:" << KurooConfig::fileWorld();
+	}
 }
 
 ////////////////////////////////////////////////////////////////////////////////////////
@@ -466,8 +488,8 @@ void Portage::removeFromWorld( const QStringList& packageList )
 void Portage::pretendPackageList( const QStringList& packageIdList )
 {
 	QStringList packageList;
-	foreach ( QString id, packageIdList )
-		packageList += KurooDBSingleton::Instance()->category( id ) + "/" + KurooDBSingleton::Instance()->package( id );
+	for ( const QString& id : packageIdList )
+		packageList += KurooDBSingleton::Instance()->category( id ) % u'/' % KurooDBSingleton::Instance()->package( id );
 
 	EmergeSingleton::Instance()->pretend( packageList );
 }
@@ -480,8 +502,8 @@ void Portage::pretendPackageList( const QStringList& packageIdList )
 void Portage::uninstallInstalledPackageList( const QStringList& packageIdList )
 {
 	QStringList packageList;
-	foreach ( QString id, packageIdList )
-		packageList += KurooDBSingleton::Instance()->category( id ) + "/" + KurooDBSingleton::Instance()->package( id );
+	for ( const QString& id : packageIdList )
+		packageList += KurooDBSingleton::Instance()->category( id ) % u'/' % KurooDBSingleton::Instance()->package( id );
 
 	EmergeSingleton::Instance()->unmerge( packageList );
 }
@@ -491,9 +513,9 @@ void Portage::uninstallInstalledPackageList( const QStringList& packageIdList )
 * Add package as installed in db.
 * @param package
 */
-void Portage::addInstalledPackage( const QString& package )
+void Portage::addInstalledPackage( const QString& package ) const
 {
-	AddInstalledPackageJob *job = new AddInstalledPackageJob( package );
+	auto *job = new AddInstalledPackageJob( package );
 	connect(job, &AddInstalledPackageJob::done, this, &Portage::slotWeaverDone);
 	ThreadWeaver::Queue::instance()->stream() << job;
 }
@@ -502,9 +524,9 @@ void Portage::addInstalledPackage( const QString& package )
 * Remove packages from db. @todo: Check for failure.
 * @param packageIdList
 */
-void Portage::removeInstalledPackage( const QString& package )
+void Portage::removeInstalledPackage( const QString& package ) const
 {
-	RemoveInstalledPackageJob *job = new RemoveInstalledPackageJob( package );
+	auto *job = new RemoveInstalledPackageJob( package );
 	connect(job, &RemoveInstalledPackageJob::done, this, &Portage::slotWeaverDone);
 	ThreadWeaver::Queue::instance()->stream() << job;
 }
@@ -513,7 +535,7 @@ void Portage::removeInstalledPackage( const QString& package )
 * Start scan of update packages.
 * @return bool
 */
-bool Portage::slotRefreshUpdates()
+auto Portage::slotRefreshUpdates() -> bool
 {
 	EmergeSingleton::Instance()->checkUpdates();
 	return true;
@@ -523,10 +545,10 @@ bool Portage::slotRefreshUpdates()
 * Start scan of update packages.
 * @return bool
 */
-bool Portage::slotLoadUpdates()
+auto Portage::slotLoadUpdates() -> bool
 {
 	SignalistSingleton::Instance()->scanStarted();
-	ScanUpdatesJob *job = new ScanUpdatesJob( EmergeSingleton::Instance()->packageList() );
+	auto *job = new ScanUpdatesJob( EmergeSingleton::Instance()->packageList() );
 	connect(job, &ScanUpdatesJob::done, this, &Portage::slotWeaverDone);
 	ThreadWeaver::Queue::instance()->stream() << job;
 	return true;
@@ -535,14 +557,14 @@ bool Portage::slotLoadUpdates()
 /**
 * Update packages when user changes package stability.
 */
-void Portage::checkUpdates( const QString& id, const QString& emergeVersion, int hasUpdate )
+void Portage::checkUpdates( const QString& id, const QString& emergeVersion, int hasUpdate ) const
 {
-	CheckUpdatesPackageJob *job = new CheckUpdatesPackageJob( id, emergeVersion, hasUpdate );
+	auto *job = new CheckUpdatesPackageJob( id, emergeVersion, hasUpdate );
 	connect(job, &CheckUpdatesPackageJob::done, this, &Portage::slotWeaverDone);
 	ThreadWeaver::Queue::instance()->stream() << job;
 }
 
-void Portage::slotWeaverDone(ThreadWeaver::JobPointer job)
+void Portage::slotWeaverDone(const ThreadWeaver::JobPointer& job)
 {
 	Q_UNUSED(job);
 	DEBUG_LINE_INFO;
@@ -550,3 +572,5 @@ void Portage::slotWeaverDone(ThreadWeaver::JobPointer job)
 	//delete job;
 }
 
+
+#include "portage.moc"
