@@ -18,35 +18,49 @@
  *	59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.				*
  ****************************************************************************/
 
-#include <unistd.h>
+#include <klocalizedstring.h>    // for i18n
+#include <kmessagebox.h>         // for questionYesNo, Yes
+#include <kstandardguiitem.h>    // for no, yes
+#include <qabstractitemmodel.h>  // for QModelIndex
+#include <qaction.h>             // for QAction
+#include <qbrush.h>              // for QBrush
+#include <qbuttongroup.h>        // for QButtonGroup
+#include <qcolor.h>              // for QColor
+#include <qcursor.h>             // for QCursor
+#include <qdebug.h>              // for QDebug
+#include <qframe.h>              // for QFrame
+#include <qglobal.h>             // for foreach
+#include <qgroupbox.h>           // for QGroupBox
+#include <qicon.h>               // for QIcon
+#include <qlineedit.h>           // for QLineEdit
+#include <qlist.h>               // for QList
+#include <qmenu.h>               // for QMenu
+#include <qnamespace.h>          // for white, CustomContextMenu
+#include <qpalette.h>            // for QPalette, QPalette::NoRole, QPalette...
+#include <qpushbutton.h>         // for QPushButton
+#include <qradiobutton.h>        // for QRadioButton
+#include <qstringlist.h>         // for QStringList
+#include <qstringliteral.h>      // for QStaticStringData, QStringLiteral
+#include <qtextbrowser.h>        // for QTextBrowser
+#include <qtimer.h>              // for QTimer
+#include <qwhatsthis.h>          // for QWhatsThis
+#include <unistd.h>              // for getuid
 
-#include "common.h"
-#include "search.h"
-#include "categorieslistview.h"
+#include "categorieslistview.h"  // for CategoriesListView, SubCategoriesLis...
+#include "common.h"              // for SignalistSingleton, EmergeSingleton
+#include "emerge.h"              // for Emerge
+#include "packageinspector.h"    // for PackageInspector
+#include "packagelistitem.h"     // for PackageListItem
+#include "portage.h"             // for Portage
+#include "portagedb.h"           // for KurooDB
+#include "portagelistview.h"     // for PortageListView
 #include "portagetab.h"
-#include "packageinspector.h"
-#include "packageversion.h"
-#include "versionview.h"
-#include "uninstallinspector.h"
-#include "ui_portagebase.h"
-#include "packagelistmodel.h"
-#include "packagelistitem.h"
+#include "queue.h"               // for Queue
+#include "settings.h"            // for KurooConfig
+#include "signalist.h"           // for Signalist
+#include "uninstallinspector.h"  // for UninstallInspector
 
-#include <QAction>
-#include <QButtonGroup>
-#include <QGroupBox>
-#include <QMenu>
-#include <QTimer>
-#include <QWhatsThis>
-
-/*#include <QPushButton>
-#include <QTextBrowser>
-#include <QLineEdit>
-#include <kiconloader.h>*/
-//#include <kaccel.h>
-#include <KButtonGroup>
-#include <KMessageBox>
-#include <KUser>
+class QPoint;
 
 enum Focus {
 		CATEGORYLIST,
@@ -60,11 +74,17 @@ enum Focus {
  */
 PortageTab::PortageTab( QWidget* parent, PackageInspector *packageInspector )
 	: QWidget( parent ), m_focusWidget( PACKAGELIST ), m_delayFilters( 0 ),
-	m_packageInspector( packageInspector ), m_uninstallInspector( 0 )
+	m_packageInspector( packageInspector ), m_uninstallInspector( nullptr )
 {
 	setupUi( this );
 
-	filterGroup->setSelected(0);
+	filterButtonGroup = new QButtonGroup();
+	filterButtonGroup->addButton(radioAll, 0);
+	filterButtonGroup->addButton(radioInstalled, 1);
+	filterButtonGroup->addButton(radioUpdates, 2);
+	filterGroup->setChecked(true);
+	//filterButtonGroup->setSelected(1);
+	//filterGroup->setSelected(0);
 	//kdDebug() << "PortageTab.constructor categoryView minimumWidth=" << categoriesView->minimumWidth()
 	//		<< "actual width=" << categoriesView->width();
 	// Connect What's this button
@@ -72,7 +92,7 @@ PortageTab::PortageTab( QWidget* parent, PackageInspector *packageInspector )
 	connect(pbWhatsThis, &QPushButton::clicked, this, &PortageTab::slotWhatsThis);
 
 	// Connect the filters
-	connect(filterGroup, &KButtonGroup::released, this, &PortageTab::slotFilters);
+	connect(filterButtonGroup, &QButtonGroup::idClicked, this, &PortageTab::slotFilters);
 	connect(searchFilter, &QLineEdit::textChanged, this, &PortageTab::slotFilters);
 
 	// Rmb actions.
@@ -103,13 +123,13 @@ PortageTab::PortageTab( QWidget* parent, PackageInspector *packageInspector )
 
 	// Toggle Queue button between "add/remove" when after queue has been edited
 	//connect( QueueSingleton::Instance(), SIGNAL( signalQueueChanged( bool ) ), this, SLOT( slotButtons() ) );
-	connect( SignalistSingleton::Instance(), SIGNAL( signalPackageQueueChanged() ), this, SLOT( slotButtons() ) );
+	connect( SignalistSingleton::Instance(), &Signalist::signalPackageQueueChanged, this, &PortageTab::slotButtons );
 
 	// Reload view after changes.
-	connect( PortageSingleton::Instance(), SIGNAL( signalPortageChanged() ), this, SLOT( slotReload() ) );
+	connect( PortageSingleton::Instance(), &Portage::signalPortageChanged, this, &PortageTab::slotReload );
 
 	// Enable/disable this view and buttons when kuroo is busy
-	connect( SignalistSingleton::Instance(), SIGNAL( signalKurooBusy( bool ) ), this, SLOT( slotBusy() ) );
+	connect( SignalistSingleton::Instance(), &Signalist::signalKurooBusy, this, &PortageTab::slotBusy );
 
 	// Load Inspector with current package info
 	connect(packagesView, &PortageListView::selectionChangedSignal, this, &PortageTab::slotPackage);
@@ -123,13 +143,13 @@ PortageTab::PortageTab( QWidget* parent, PackageInspector *packageInspector )
 	connect(m_packageInspector, &PackageInspector::finished, this, &PortageTab::slotButtons);
 
 	// Shortcut to enter filter with package name
-	connect( SignalistSingleton::Instance(), SIGNAL( signalPackageClicked( const QString& ) ), this, SLOT( slotFillFilter( const QString& ) ) );
+	connect( SignalistSingleton::Instance(), &Signalist::signalPackageClicked, this, &PortageTab::slotFillFilter );
 
 	slotInit();
 }
 
 PortageTab::~PortageTab()
-{}
+= default;
 
 /**
  * Initialize Portage view.
@@ -250,11 +270,9 @@ void PortageTab::slotButtons()
 {
 	if ( m_packageInspector->isVisible() )
 		return;
-	else {
-		filterGroup->setDisabled( false );
-		searchFilter->setDisabled( false );
-		pbClearFilter->setDisabled( false );
-	}
+	filterGroup->setDisabled( false );
+	searchFilter->setDisabled( false );
+	pbClearFilter->setDisabled( false );
 
 	// No current package, disable all buttons
 	if ( packagesView->selectedPackages().isEmpty()) {
@@ -273,8 +291,7 @@ void PortageTab::slotButtons()
 		pbUninstall->setDisabled( true );
 		return;
 	}
-	else
-		pbQueue->setDisabled( false );
+	pbQueue->setDisabled( false );
 
 	// Toggle queue button between add/remove
 	if ( packagesView->currentPackage()) {
@@ -294,7 +311,7 @@ void PortageTab::slotButtons()
 			connect(pbQueue, &QPushButton::clicked, this, &PortageTab::slotEnqueue);
 			pbQueue->setText( i18n("Add to Queue") );
 		}
-		if (packagesView->currentPackage()->isInstalled() && ::getuid() == 0)
+		if (packagesView->currentPackage()->isInstalled())
 			pbUninstall->setDisabled( false );
 		else
 			pbUninstall->setDisabled( true );
@@ -302,11 +319,14 @@ void PortageTab::slotButtons()
 	else if (packagesView->selectedPackages().count() > 1) {
 		pbQueue->setDisabled( false );
 		int queued = 0, installed = 0;
-		foreach(PackageListItem *item, packagesView->selectedPackages())
+		// declaring a local const container prevents detaching and the attendant clazy warning
+		// In C++20 the range for can do this in the loop declaration https://www.kdab.com/blog-qasconst-and-stdas_const/
+		const QList<PackageListItem*> selected = packagesView->selectedPackages();
+		for(PackageListItem *item : selected)
 		{
 			if (QueueSingleton::Instance()->isQueued(item->id()))
 				queued++;
-			if (item->isInstalled() && ::getuid() == 0)
+			if (item->isInstalled())
 				installed++;
 		}
 
@@ -366,7 +386,7 @@ void PortageTab::slotReload()
 	connect(categoriesView, &CategoriesListView::currentItemChanged, this, &PortageTab::slotListSubCategories);
 	connect(subcategoriesView, &SubCategoriesListView::currentItemChanged, this, &PortageTab::slotListPackages);
 
-	categoriesView->loadCategories( KurooDBSingleton::Instance()->portageCategories( 1 << filterGroup->selected(), searchFilter->text() )/*, false */);
+	categoriesView->loadCategories( KurooDBSingleton::Instance()->portageCategories( 1 << filterButtonGroup->checkedId(), searchFilter->text() )/*, false */);
 }
 
 void PortageTab::slotFillFilter( const QString& text )
@@ -380,7 +400,7 @@ void PortageTab::slotFillFilter( const QString& text )
 void PortageTab::slotFilters()
 {
 	m_delayFilters++;
-	QTimer::singleShot( 250, this, SLOT( slotActivateFilters() ) );
+	QTimer::singleShot( 250, this, &PortageTab::slotActivateFilters );
 }
 
 /**
@@ -390,7 +410,7 @@ void PortageTab::slotActivateFilters()
 {
 	--m_delayFilters;
 	if ( m_delayFilters == 0 )
-		categoriesView->loadCategories( KurooDBSingleton::Instance()->portageCategories( 1 << filterGroup->selected(), searchFilter->text() )/*, true */);
+		categoriesView->loadCategories( KurooDBSingleton::Instance()->portageCategories( 1 << filterButtonGroup->checkedId(), searchFilter->text() )/*, true */);
 }
 
 /**
@@ -399,7 +419,7 @@ void PortageTab::slotActivateFilters()
 void PortageTab::slotListSubCategories()
 {
 	subcategoriesView->loadCategories( KurooDBSingleton::Instance()->portageSubCategories( categoriesView->currentCategoryId(),
-		1 << filterGroup->selected(), searchFilter->text() ) );
+		1 << filterButtonGroup->checkedId(), searchFilter->text() ) );
 }
 
 /**
@@ -407,11 +427,10 @@ void PortageTab::slotListSubCategories()
  */
 void PortageTab::slotListPackages()
 {
-	int numberOfTerms = 0; //For singular or plural message
 	// Disable all buttons if query result is empty
 	QStringList dbres = KurooDBSingleton::Instance()->portagePackagesBySubCategory(categoriesView->currentCategoryId(),
 										       subcategoriesView->currentCategoryId(),
-										       1 << filterGroup->selected(),
+										       1 << filterButtonGroup->checkedId(),
 										       searchFilter->text());
 
 	packagesView->setPackages(dbres);
@@ -419,26 +438,6 @@ void PortageTab::slotListPackages()
 		m_packageInspector->hide();
 		slotButtons();
 		summaryBrowser->clear();
-		if (radioUpdates->isChecked())
-			numberOfTerms = -1;
-		else {
-			/*** We check number of terms to pass to showNoHitsWarning **/
-			QChar space((char)32);
-			bool iscounted=false;
-			for (int i = 0; i < searchFilter->text().length(); i++) {
-				if (searchFilter->text()[i] != space) {
-					if (!iscounted) numberOfTerms++;
-					iscounted = true;
-				}
-				else {
-					iscounted = false;
-				}
-			}
-		}
-		qDebug() << numberOfTerms;
-		//FIXME:implement this
-		//packagesView->showNoHitsWarning( true , numberOfTerms );
-
 		//TODO: This forces white instead of using the current color-scheme default
 		// Highlight text filter background in red if query failed
 		if ( !searchFilter->text().isEmpty() )
@@ -458,9 +457,6 @@ void PortageTab::slotListPackages()
 		}
 	}
 	else {
-		//FIXME:implement this
-		//packagesView->showNoHitsWarning( false , numberOfTerms );
-
 		// Highlight text filter background in green if query successful
 		if ( !searchFilter->text().isEmpty() )
 		{
@@ -492,11 +488,11 @@ void PortageTab::slotClearFilter()
  */
 void PortageTab::slotRefresh()
 {
-	switch( KMessageBox::questionYesNo( this,
+	switch( KMessageBox::questionTwoActions( this,
 		i18n( "<qt>Do you want to refresh the Packages view?<br>"
 			  "This will take a couple of minutes...</qt>"), i18n( "Refreshing Packages" ),
-										KStandardGuiItem::yes(), KStandardGuiItem::no(), "dontAskAgainRefreshPortage" ) ) {
-		case KMessageBox::Yes:
+										KGuiItem( i18n("refresh"), QStringLiteral("refresh_view") ), KStandardGuiItem::cancel(), QStringLiteral("dontAskAgainRefreshPortage") ) ) {
+		case KMessageBox::PrimaryAction:
 			PortageSingleton::Instance()->slotRefresh();
 		default:
 			break;
@@ -511,7 +507,7 @@ void PortageTab::slotEnqueue()
 	if ( !EmergeSingleton::Instance()->isRunning() || !SignalistSingleton::Instance()->isKurooBusy() ) {
 		const QStringList selectedIdsList = packagesView->selectedPackagesByIds();
 		QStringList packageIdList;
-		foreach( QString id, selectedIdsList )
+		for( const QString& id : selectedIdsList )
 		{
 			if ( packagesView->packageItemById( id )->isInPortage() && !packagesView->packageItemById( id )->isQueued() )
 			{
@@ -544,10 +540,10 @@ void PortageTab::slotUninstall()
 
 		// Pick only installed packages
 		QStringList packageList;
-		foreach ( QString id, selectedIdsList ) {
+		for ( const QString& id : selectedIdsList ) {
 			if ( packagesView->packageItemById( id )->isInstalled() ) {
 				packageList += id;
-				packageList += packagesView->packageItemById( id )->category() + "/" + packagesView->packageItemById( id )->name();
+				packageList += packagesView->packageItemById( id )->category() + u'/' + packagesView->packageItemById( id )->name();
 			}
 		}
 
@@ -559,8 +555,8 @@ void PortageTab::slotAddWorld()
 {
 	const QStringList selectedIdsList = packagesView->selectedPackagesByIds();
 	QStringList packageList;
-	foreach ( QString id, selectedIdsList )
-		packageList += packagesView->packageItemById( id )->category() + "/" + packagesView->packageItemById( id )->name();
+	for ( const QString& id : selectedIdsList )
+		packageList += packagesView->packageItemById( id )->category() + u'/' + packagesView->packageItemById( id )->name();
 	PortageSingleton::Instance()->appendWorld( packageList );
 }
 
@@ -568,8 +564,8 @@ void PortageTab::slotRemoveWorld()
 {
 	const QStringList selectedIdsList = packagesView->selectedPackagesByIds();
 	QStringList packageList;
-	foreach ( QString id, selectedIdsList )
-		packageList += packagesView->packageItemById( id )->category() + "/" + packagesView->packageItemById( id )->name();
+	for ( const QString& id : selectedIdsList )
+		packageList += packagesView->packageItemById( id )->category() + u'/' + packagesView->packageItemById( id )->name();
 	PortageSingleton::Instance()->removeFromWorld( packageList );
 }
 
@@ -577,9 +573,9 @@ void PortageTab::slotBackup()
 {
 	const QStringList selectedIdsList = packagesView->selectedPackagesByIds();
 	QStringList packageList;
-	foreach( QString id, selectedIdsList ) {
+	for( const QString& id : selectedIdsList ) {
 		if( packagesView->packageItemById( id )->isInstalled() && packagesView->packageItemById( id )->isInPortage() )
-			packageList += packagesView->packageItemById( id )->category() + "/" + packagesView->packageItemById( id )->name();
+			packageList += packagesView->packageItemById( id )->category() + u'/' + packagesView->packageItemById( id )->name();
 	}
 	EmergeSingleton::Instance()->quickpkg( packageList );
 }
@@ -631,21 +627,17 @@ void PortageTab::processPackage( bool viewInspector )
 	if ( count > 1 ) {
 
 		// Build summary html-view
-		QString lines = "<table width=100% border=0 cellpadding=0>";
-		lines += "<tr><td colspan=2><font";
-		//bgcolor=#" + GlobalSingleton::Instance()->bgHexColor() + "
-		//lines += "color=#"GlobalSingleton::Instance()->fgHexColor()
-		lines += " size=+1><b>";
-		lines += QString::number( count ) + i18n( " packages selected" ) + "</b></font></td></tr>";
-		lines += "<tr><td>";
-		foreach ( QString id, selectedIdsList ) {
-			lines += packagesView->packageItemById( id )->name();
-			lines += " (" + packagesView->packageItemById( id )->category().section( "-", 0, 0 ) + "/";
-			lines += packagesView->packageItemById( id )->category().section( "-", 1, 1 ) + "), ";
+		QString lines = QStringLiteral("<table width=100% border=0 cellpadding=0>"
+			"<tr><td colspan=2><font size=+1><b>%1%2</b></font></td></tr>"
+			"<tr><td>").arg( QString::number( count ), i18n( " packages selected" ) );
+		for ( const QString& id : selectedIdsList ) {
+			lines += QStringLiteral("%1 (%2/%3), ").arg( packagesView->packageItemById( id )->name(),
+														 packagesView->packageItemById( id )->category().section( u'-', 0, 0 ),
+														 packagesView->packageItemById( id )->category().section( u'-', 1, 1 ) );
 		}
-		lines = lines.left( lines.length() - 2 );
-		lines += "</td></tr>";
-		summaryBrowser->setText( lines + "</table>");
+		lines = lines.left( lines.length() - 2 );	//strip off trailing ', '
+		lines += QStringLiteral("</td></tr></table>");
+		summaryBrowser->setText( lines );
 
 		pbAdvanced->setDisabled( true );
 		return;
@@ -663,90 +655,65 @@ void PortageTab::processPackage( bool viewInspector )
 	QString linesEmerge = package->linesEmerge();
 
 	// Build summary html-view
-	QString lines = "<table width=100% border=0 cellpadding=0>";
-			lines += "<tr><td";
-			//"bgcolor=#" + GlobalSingleton::Instance()->bgHexColor();
-			lines += " colspan=2><b>";
-			//lines += "<font color=#" + GlobalSingleton::Instance()->fgHexColor() + ">"
-			lines += "<font size=+1>" + package->name() + "</font> ";
-			lines += "(" + package->category().section( "-", 0, 0 ) + "/";
-			lines += package->category().section( "-", 1, 1 ) + ")</font></b></td></tr>";
+	QString lines = QStringLiteral("<table width=100% border=0 cellpadding=0>"
+			"<tr><td colspan=2><b><font size=+1>%1</font> (%2/%3)</font></b></td></tr>")
+		.arg( package->name(), package->category().section( u'-', 0, 0 ), package->category().section( u'-', 1, 1 ));
 
 	if ( package->isInPortage() ) {
-		lines += "<tr><td colspan=2>" + package->description() + "</td></tr>";
-		lines += "<tr><td colspan=2>" + i18n( "<b>Homepage: </b>" ) + "<a href=\"" + package->homepage();
-		lines += "\">" + package->homepage() + "</a></td></tr>";
+		lines += QStringLiteral("<tr><td colspan=2>%1</td></tr><tr><td colspan=2>%2<a href=\"%3\">%3</a></td></tr>")
+			.arg( package->description(), i18n( "<b>Homepage: </b>" ), package->homepage() );
 	}
 	else {
-		lines += "<tr><td colspan=2><font color=darkRed><b>"
+		lines += QStringLiteral("<tr><td colspan=2><font color=darkRed><b>")
 				+ i18n( "Package not available in Portage tree anymore!" )
-				+ "</b></font></td></tr>";
+				+ QStringLiteral("</b></font></td></tr>");
 	}
 
 	// Construct installed verions line
 	if ( !linesInstalled.isEmpty() ) {
-		linesInstalled = "<tr><td width=10%><b>"
-						+ i18n( "Installed&nbsp;version:" )
-						+ "</b></font></td><td width=90%>"
-						+ linesInstalled
-						+ "</td></tr>";
+		linesInstalled = QStringLiteral("<tr><td width=15%><b>%1</b></font></td><td width=85%>%2</td></tr>")
+			.arg( i18n( "Installed&nbsp;version:" ), linesInstalled );
 	}
 	else {
-		linesInstalled = "<tr><td width=10%><b>"
+		linesInstalled = QStringLiteral("<tr><td width=15%><b>")
 						+ i18n( "Installed&nbsp;version:" )
-						+ "</b></font></td><td width=90%>"
-						+ "Not installed"
-						+ "</td></tr>";
+						+ QStringLiteral("</b></font></td><td width=85%>"
+						"Not installed"
+						"</td></tr>");
 	}
 
 	if ( package->isInPortage() ) {
 
 		// Construct emerge version line
 		if ( !linesEmerge.isEmpty() ) {
-			linesEmerge = "<tr><td width=10%><b>"
-						+ i18n( "Emerge&nbsp;version:" )
-						+ "</b></td><td width=90%>"
-						+ linesEmerge
-						+ "</td></tr>";
+			linesEmerge = QStringLiteral("<tr><td width=15%><b>%1</b></td><td width=85%>%2</td></tr>")
+				.arg( i18n( "Emerge&nbsp;version:" ), linesEmerge );
 		}
 		else {
 			if ( package->isInArch() && linesAvailable.isEmpty() ) {
-				linesEmerge = "<tr><td width=10%><b>"
-							+ i18n( "Emerge&nbsp;version:" )
-							+ "</font></td><td width=90%><font color=darkRed>"
-							+ i18n( "No version available on" )
-							+ KurooConfig::arch()
-							+ "</b></td></tr>";
+				linesEmerge = QStringLiteral("<tr><td width=15%><b>%1</font></td><td width=85%><font color=darkRed>%2%3</b></td></tr>")
+					.arg( i18n( "Emerge&nbsp;version:" ), i18n( "No version available on" ), KurooConfig::arch() );
 			}
 			else {
-				linesEmerge = "<tr><td width=10%><b>"
-							+ i18n( "Emerge&nbsp;version:" )
-							+ "</font></td><td width=90%><font color=darkRed>"
-							+ i18n( "No version available - please check package details" )
-							+ "</font></b></td></tr>";
+				linesEmerge = QStringLiteral("<tr><td width=15%><b>%1</font></td><td width=85%><font color=darkRed>%2</font></b></td></tr>")
+					.arg( i18n( "Emerge&nbsp;version:" ), i18n( "No version available - please check package details" ) );
 			}
 		}
 
 		// Construct available versions line
 		if ( !linesAvailable.isEmpty() ) {
-			linesAvailable = "<tr><td width=10%><b>"
-							+ i18n( "Available&nbsp;versions:" )
-							+ "</b></td><td width=90%>"
-							+ linesAvailable
-							+ "</b></td></tr>";
+			linesAvailable = QStringLiteral("<tr><td width=15%><b>%1</b></td><td width=85%>%2</b></td></tr>")
+				.arg( i18n( "Available&nbsp;versions:" ), linesAvailable );
 		}
 		else {
-			linesAvailable = "<tr><td width=10%><b>"
-						+ i18n( "Available&nbsp;versions:" )
-						+ "</td><td width=90%><font color=darkRed>"
-						+ i18n( "No versions available on %1", KurooConfig::arch() )
-						+ "</font></b></td></tr>";
+			linesAvailable = QStringLiteral("<tr><td width=15%><b>%1</td><td width=85%><font color=darkRed>%2</font></b></td></tr>")
+				.arg(i18n( "Available&nbsp;versions:" ) , i18n( "No versions available on %1", KurooConfig::arch() ) );
 		}
 
-		summaryBrowser->setText( lines + linesInstalled + linesEmerge + linesAvailable + "</table>" );
+		summaryBrowser->setText( lines + linesInstalled + linesEmerge + linesAvailable + QStringLiteral("</table>") );
 	}
 	else {
-		summaryBrowser->setText( lines + linesInstalled + "</table>" );
+		summaryBrowser->setText( lines + linesInstalled + QStringLiteral("</table>") );
 	}
 
 	// Refresh inspector if visible
@@ -760,7 +727,7 @@ void PortageTab::processPackage( bool viewInspector )
  * @param item
  * @param point
  */
-void PortageTab::slotContextMenu(const QPoint &point)
+void PortageTab::slotContextMenu(QPoint point)
 {
 	QModelIndex item = packagesView->indexAt(point);
 
@@ -776,7 +743,7 @@ void PortageTab::slotContextMenu(const QPoint &point)
 	bool hasInstalledPackages = false;
 	bool hasInstalledAndInPortagePackages = false;
 
-	foreach( QString id, selectedIdsList ) {
+	for( const QString& id : selectedIdsList ) {
 		PackageListItem *currentItem = packagesView->packageItemById( id );
 
 		if( currentItem->isQueued() ) {
@@ -807,9 +774,9 @@ void PortageTab::slotContextMenu(const QPoint &point)
 	menu.addAction(m_packageDetails);
 	m_packageDetails->setEnabled( selectedIdsList.count() == 1 );
 	menu.addAction(m_addToWorld);
-	m_addToWorld->setEnabled(false);	//default to false, enable later if super user
+	m_addToWorld->setEnabled(hasItemsOutOfWorld);
 	menu.addAction(m_removeFromWorld);
-	m_removeFromWorld->setEnabled(false);	//default to false, enable later if super user
+	m_removeFromWorld->setEnabled(hasItemsInWorld);
 	menu.addAction(m_uninstallPackage);
 	m_uninstallPackage->setEnabled(hasInstalledPackages);
 	menu.addAction(m_quickPackage);
@@ -864,19 +831,11 @@ void PortageTab::slotContextMenu(const QPoint &point)
 	}
 
 	// No uninstall when emerging or no privileges
-	if ( busy || !KUser().isSuperUser() ) {
+	if ( busy ) {
 		//menu.setItemEnabled( uninstallMenuItem, false );
 		m_uninstallPackage->setDisabled(true);
 	}
 
-	// Allow editing of World when superuser
-	if ( KUser().isSuperUser() ) {
-		//menu.setItemEnabled( addWorldMenuItem, hasItemsOutOfWorld );
-		//menu.setItemEnabled( delWorldMenuItem, hasItemsInWorld );
-		m_addToWorld->setEnabled(hasItemsOutOfWorld);
-		m_removeFromWorld->setEnabled(hasItemsInWorld);
-	}
-
 	if ( m_packageInspector->isVisible() ) {
 // 		menu.setItemEnabled( enqueueMenuItem, false );
 // 		menu.setItemEnabled( dequeueMenuItem, false );
