@@ -18,32 +18,49 @@
  *	59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.				*
  ***************************************************************************/
 
-#include "common.h"
-#include "statusbar.h"
+#include <klocalizedstring.h>    // for i18n
+#include <kmessagebox.h>         // for questionYesNoList, Yes, warningYesNo
+#include <kstandardguiitem.h>    // for no, yes
+#include <qabstractitemmodel.h>  // for QModelIndex
+#include <qaction.h>             // for QAction
+#include <qcheckbox.h>           // for QCheckBox
+#include <qcursor.h>             // for QCursor
+#include <qdebug.h>              // for QDebug, operator<<
+#include <qglobal.h>             // for qDebug, foreach
+#include <qicon.h>               // for QIcon
+#include <qlist.h>               // for QList
+#include <qmenu.h>               // for QMenu
+#include <qnamespace.h>          // for CustomContextMenu
+#include <qpushbutton.h>         // for QPushButton
+#include <qstringlist.h>         // for QStringList
+#include <qstringliteral.h>      // for QStaticStringData, QStringLiteral
+#include <qtextbrowser.h>        // for QTextBrowser
+#include <qwhatsthis.h>          // for QWhatsThis
+
+#include "common.h"              // for QueueSingleton, EmergeSingleton, Sig...
+#include "emerge.h"              // for Emerge
+#include "global.h"              // for formatTime
+#include "log.h"                 // for Log
+#include "packageinspector.h"    // for PackageInspector
+#include "packagelistitem.h"     // for PackageListItem
+#include "portage.h"             // for Portage
+#include "portagedb.h"           // for KurooDB
+#include "queue.h"               // for Queue
+#include "queuelistitem.h"       // for QueueListItem
+#include "queuelistview.h"       // for QueueListView
 #include "queuetab.h"
-#include "queuelistitem.h"
-#include "queuelistview.h"
-#include "packageinspector.h"
-#include "versionview.h"
-#include "packageversion.h"
-#include "ui_queuebase.h"
+#include "settings.h"            // for KurooConfig
+#include "signalist.h"           // for Signalist
+#include "statusbar.h"           // for KurooStatusBar
 
-#include <QCheckBox>
-#include <QWhatsThis>
-
-#include <QPushButton>
-#include <KMessageBox>
-#include <QMenu>
-#include <KUser>
-//#include <kaccel.h>
-#include <QAction>
+class QPoint;
 
 /**
 * @class QueueTab
 * @short Page for the installation queue.
 */
 QueueTab::QueueTab( QWidget* parent, PackageInspector *packageInspector )
-	: QWidget( parent ), m_hasCheckedQueue( false ), m_initialQueueTime( QString::null ), m_packageInspector( packageInspector )
+	: QWidget( parent ), m_hasCheckedQueue( false ), m_initialQueueTime( QString() ), m_packageInspector( packageInspector )
 {
 	setupUi( this );
 	// Connect What's this button
@@ -77,20 +94,20 @@ QueueTab::QueueTab( QWidget* parent, PackageInspector *packageInspector )
 	connect(queueView, &QueueListView::selectionChangedSignal, this, &QueueTab::slotButtons);
 
 	// Lock/unlock if kuroo is busy
-	connect( SignalistSingleton::Instance(), SIGNAL( signalKurooBusy( bool ) ), this, SLOT( slotBusy() ) );
+	connect( SignalistSingleton::Instance(), &Signalist::signalKurooBusy, this, &QueueTab::slotBusy );
 
 	// Reload view after changes in queue.
-	connect( QueueSingleton::Instance(), SIGNAL( signalQueueChanged( bool ) ), this, SLOT( slotReload( bool ) ) );
-	connect( PortageSingleton::Instance(), SIGNAL( signalPortageChanged() ), this, SLOT( slotRefresh() ) );
+	connect( QueueSingleton::Instance(), &Queue::signalQueueChanged, this, &QueueTab::slotReload );
+	connect( PortageSingleton::Instance(), &Portage::signalPortageChanged, this, &QueueTab::slotRefresh );
 
 	// Forward emerge start/stop/completed to package progressbar.
-	connect( QueueSingleton::Instance(), SIGNAL( signalPackageStart( const QString& ) ), queueView, SLOT( slotPackageStart( const QString& ) ) );
-	connect( QueueSingleton::Instance(), SIGNAL( signalPackageComplete( const QString& ) ), queueView, SLOT( slotPackageComplete( const QString& ) ) );
-	connect( QueueSingleton::Instance(), SIGNAL( signalPackageAdvance() ), queueView, SLOT( slotPackageProgress() ) );
+	connect( QueueSingleton::Instance(), &Queue::signalPackageStart, queueView, &QueueListView::slotPackageStart );
+	connect( QueueSingleton::Instance(), &Queue::signalPackageComplete, queueView, &QueueListView::slotPackageComplete );
+	connect( QueueSingleton::Instance(), &Queue::signalPackageAdvance, queueView, &QueueListView::slotPackageProgress );
 
 	// Update Queue summary timer
-	connect( QueueSingleton::Instance(), SIGNAL( signalPackageAdvance() ), this, SLOT( slotQueueSummary() ) );
-	connect( QueueSingleton::Instance(), SIGNAL( signalPackageComplete( const QString& ) ), this, SLOT( slotQueueSummary() ) );
+	connect( QueueSingleton::Instance(), &Queue::signalPackageAdvance, this, &QueueTab::slotQueueSummary );
+	connect( QueueSingleton::Instance(), &Queue::signalPackageComplete, this, &QueueTab::slotQueueSummary );
 
 	// Recalculate package when user change settings in Inspector
 	connect(m_packageInspector, &PackageInspector::signalPackageChanged, this, &QueueTab::slotPackage);
@@ -105,30 +122,12 @@ QueueTab::QueueTab( QWidget* parent, PackageInspector *packageInspector )
 */
 QueueTab::~QueueTab()
 {
-	if ( cbForceConf->isChecked() )
-		KurooConfig::setForceConf( true );
-	else
-		KurooConfig::setForceConf( false );
-
-	if ( cbDownload->isChecked() )
-		KurooConfig::setDownload( true );
-	else
-		KurooConfig::setDownload( false );
-
-	if ( cbNoWorld->isChecked() )
-		KurooConfig::setNoWorld( true );
-	else
-		KurooConfig::setNoWorld( false );
-
-	if ( cbRemove->isChecked() )
-		KurooConfig::setRemove( true );
-	else
-		KurooConfig::setRemove( false );
-
-	if ( cbBackupPkg->isChecked() )
-		KurooConfig::setBackupPkg( true );
-	else
-		KurooConfig::setBackupPkg( false );
+	KurooConfig::setForceConf( cbForceConf->isChecked() );
+	KurooConfig::setDownload( cbDownload->isChecked() );
+	KurooConfig::setNoWorld( cbNoWorld->isChecked() );
+	KurooConfig::setRemove( cbRemove->isChecked() );
+	KurooConfig::setBackupPkg( cbBackupPkg->isChecked() );
+	KurooConfig::setUpdateNewUse( cbUpdate->isChecked() );
 
 	if ( KurooConfig::enableEclean() || KurooConfig::revdepEnabled() )
 		cbSkipHousekeeping->setDisabled( false );
@@ -142,31 +141,12 @@ QueueTab::~QueueTab()
 void QueueTab::slotInit()
 {
 	//queueFrame->setPaletteBackgroundColor( colorGroup().base() );
-
-	if ( KurooConfig::forceConf() )
-		cbForceConf->setChecked( true );
-	else
-		cbForceConf->setChecked( false );
-
-	if ( KurooConfig::download() )
-		cbDownload->setChecked( true );
-	else
-		cbDownload->setChecked( false );
-
-	if ( KurooConfig::noWorld() )
-		cbNoWorld->setChecked( true );
-	else
-		cbNoWorld->setChecked( false );
-
-	if ( KurooConfig::remove() )
-		cbRemove->setChecked( true );
-	else
-		cbRemove->setChecked( false );
-
-	if ( KurooConfig::backupPkg() )
-		cbBackupPkg->setChecked( true );
-	else
-		cbBackupPkg->setChecked( false );
+	cbForceConf->setChecked( KurooConfig::forceConf() );
+	cbDownload->setChecked( KurooConfig::download() );
+	cbNoWorld->setChecked( KurooConfig::noWorld() );
+	cbRemove->setChecked( KurooConfig::remove() );
+	cbBackupPkg->setChecked( KurooConfig::backupPkg() );
+	cbUpdate->setChecked( KurooConfig::updateNewUse() );
 
 	if ( KurooConfig::enableEclean() || KurooConfig::revdepEnabled() )
 		cbSkipHousekeeping->setDisabled( false );
@@ -258,11 +238,7 @@ void QueueTab::slotReload( bool hasCheckedQueue )
 	// Reenable the inspector after queue changes
 	//m_packageInspector->setDisabled( true );
 	pbAdvanced->setDisabled( true );
-
-	// If user is not su emerge pretend will not set packages as checked
 	m_hasCheckedQueue = hasCheckedQueue;
-	if ( m_hasCheckedQueue && !KUser().isSuperUser() )
-		m_hasCheckedQueue = false;
 
 	// Load all packages
 	slotRefresh();
@@ -285,10 +261,10 @@ void QueueTab::slotQueueSummary()
 {
 	queueBrowser->clear();
 	QString queueBrowserLines(   i18n( "<table width=100% border=0 cellpadding=0><tr><td colspan=2><b>Summary</b></td></tr>" ) );
-			queueBrowserLines += i18n( "<tr><td width=10%>Number&nbsp;of&nbsp;packages:</td><td> %1</td></tr>", queueView->count() );
-			queueBrowserLines += i18n( "<tr><td width=10%>Initial&nbsp;estimated&nbsp;time:</td><td> %1</td></tr>", m_initialQueueTime );
-			queueBrowserLines += i18n( "<tr><td width=10%>Elapsed&nbsp;time:</td><td> %1</td></tr>", formatTime( KurooStatusBar::instance()->elapsedTime() ) );
-			queueBrowserLines += i18n( "<tr><td width=10%>Estimated&nbsp;time&nbsp;remaining:</td><td> %1</td></tr></table>", formatTime( queueView->totalDuration() ) );
+			queueBrowserLines += i18n( "<tr><td>Number&nbsp;of&nbsp;packages:</td><td> %1</td></tr>", queueView->count() );
+			queueBrowserLines += i18n( "<tr><td>Initial&nbsp;estimated&nbsp;time:</td><td> %1</td></tr>", m_initialQueueTime );
+			queueBrowserLines += i18n( "<tr><td>Elapsed&nbsp;time:</td><td> %1</td></tr>", formatTime( KurooStatusBar::instance()->elapsedTime() ) );
+			queueBrowserLines += i18n( "<tr><td>Estimated&nbsp;time&nbsp;remaining:</td><td> %1</td></tr></table>", formatTime( queueView->totalDuration() ) );
 	queueBrowser->setText( queueBrowserLines );
 }
 
@@ -303,6 +279,8 @@ void QueueTab::slotBusy()
 {
 	// No db or queue is empty - no fun!
 	if ( !SignalistSingleton::Instance()->isKurooReady() || KurooDBSingleton::Instance()->isQueueEmpty() ) {
+		if ( !SignalistSingleton::Instance()->isKurooReady() )
+			qDebug() << "QueueTab.slotBusy kuroo is busy";
 		pbRemove->setDisabled( true );
 		pbAdvanced->setDisabled( true );
 		pbClear->setDisabled( true );
@@ -325,6 +303,7 @@ void QueueTab::slotButtons()
 	if ( m_packageInspector->isVisible() )
 		return;
 
+	qDebug() << "QueueTab.slotButtons, emerge is running" << EmergeSingleton::Instance()->isRunning() << "m_hasCheckedQueue" << m_hasCheckedQueue;
 	// Kuroo is busy emerging toggle to "abort"
 	if ( EmergeSingleton::Instance()->isRunning() ) {
 		pbGo->setText( i18n( "Abort Installation" ) );
@@ -372,9 +351,8 @@ void QueueTab::slotButtons()
 			cbSkipHousekeeping->setDisabled( true );
 	}
 
-
-	// User is su and packages in queue are "checked" - enable checkboxes
-	if ( m_hasCheckedQueue && KUser().isSuperUser() ) {
+	// packages in queue are "checked" - enable checkboxes
+	if ( m_hasCheckedQueue ) {
 		pbGo->setDisabled( false );
 		cbForceConf->setDisabled( false );
 		cbNoWorld->setDisabled( false );
@@ -404,7 +382,7 @@ void QueueTab::slotCheck()
 	QStringList packageList = queueView->allPackagesNoChildren();
 	qDebug() << packageList;
 	if( cbUpdate->isChecked() )
-		packageList.prepend( "-uN" );
+		packageList.prepend( QStringLiteral("-uN") );
 	EmergeSingleton::Instance()->pretend( packageList );
 }
 
@@ -413,6 +391,7 @@ void QueueTab::slotCheck()
 */
 void QueueTab::slotGo()
 {
+	DEBUG_LINE_INFO;
 	// If emerge is running I'm the abort function
 	if ( EmergeSingleton::Instance()->isRunning() )
 		slotStop();
@@ -428,37 +407,39 @@ void QueueTab::slotGo()
 	// Only download? prepend --fetch-all-uri
 	// Else, let's install the user-end packages
 	if ( cbDownload->isChecked() ) {
-		switch( KMessageBox::questionYesNoList( this,
+		switch( KMessageBox::questionTwoActionsList( this,
 			i18n("Do you want to Download following packages?"), packageList, i18n("Installation queue"),
-			KStandardGuiItem::yes(), KStandardGuiItem::no(), "dontAskAgainDownload", KMessageBox::Dangerous ) ) {
+			KGuiItem( i18n("Download"), QStringLiteral("download") ), KStandardGuiItem::cancel(), QStringLiteral("dontAskAgainDownload"), KMessageBox::Dangerous ) ) {
 
-				case KMessageBox::Yes:
-					packageList.prepend( "--fetch-all-uri" );
-					QueueSingleton::Instance()->installQueue( packageList );
+				case KMessageBox::PrimaryAction:
+					packageList.prepend( QStringLiteral("--fetch-all-uri") );
 					KurooStatusBar::instance()->setTotalSteps( queueView->totalDuration() );
+					QueueSingleton::Instance()->installQueue( packageList );
 				default:
 					break;
 			}
 	}
 	else {
-		switch( KMessageBox::questionYesNoList( this,
+		switch( KMessageBox::questionTwoActionsList( this,
 			i18n("Do you want to install following packages?"), packageList, i18n("Installation queue"),
-			KStandardGuiItem::yes(), KStandardGuiItem::no(), "dontAskAgainInstall", KMessageBox::Dangerous ) ) {
+			KGuiItem( i18n("Install"), QStringLiteral("kuroo_view_queue")  ), KStandardGuiItem::cancel(), QStringLiteral("dontAskAgainInstall"), KMessageBox::Dangerous ) ) {
 
-				case KMessageBox::Yes: {
+				case KMessageBox::PrimaryAction: {
 					if( cbUpdate->isChecked() )
-						packageList.prepend( "-uN" );
+						packageList.prepend( QStringLiteral("-uN") );
 
 					// Force portage to reinstall files protected in CONFIG_PROTECT
 					if ( cbForceConf->isChecked() )
-						packageList.prepend( "--noconfmem" );
+						packageList.prepend( QStringLiteral("--noconfmem") );
 
 					// Emerge as normal, but do not add the packages to the @world profile for later updating.
 					if ( cbNoWorld->isChecked() )
-						packageList.prepend( "--oneshot" );
+						packageList.prepend( QStringLiteral("--oneshot") );
 
-					QueueSingleton::Instance()->installQueue( packageList );
+					// Doing 'setTotalSteps' before 'installQueue' will allow the 'stopTimer' on error inside of emerge.cpp
+					// to stop the status bar, but it will also make the status bar move while the auth dialog is waiting
 					KurooStatusBar::instance()->setTotalSteps( queueView->totalDuration() );
+					QueueSingleton::Instance()->installQueue( packageList );
 				}
 				default:
 					break;
@@ -471,21 +452,25 @@ void QueueTab::slotGo()
 */
 void QueueTab::slotStop()
 {
-	switch ( KMessageBox::warningYesNo( this,
-		i18n( "Do you want to abort the running installation?" ) ) ) {
+	qDebug() << "QueueTab::slotStop emerge is running" << EmergeSingleton::Instance()->isRunning();
+	if ( EmergeSingleton::Instance()->isRunning() ) {
+		switch ( KMessageBox::warningTwoActions( this,
+			i18n( "Do you want to abort the running installation?" ), i18n("Abort"), KGuiItem( i18n("Abort"), QStringLiteral("kuroo_warning") ), KStandardGuiItem::cont() ) ) {
 
-			case KMessageBox::Yes :
-				EmergeSingleton::Instance()->stop();
-				KurooStatusBar::instance()->setProgressStatus( QString::null, i18n("Done.") );
-				// added an explicit busy switch to allow someone to continue once
-				// an abort has happened. 20070223 - aga
-				SignalistSingleton::Instance()->setKurooBusy(false);
-				// added a log entry for the abort
-				LogSingleton::Instance()->writeLog( i18n("Emerge aborted by user."), KUROO );
-				SignalistSingleton::Instance()->emergeAborted();
-			default:
-				break;
-		}
+				case KMessageBox::PrimaryAction:
+					EmergeSingleton::Instance()->stop();
+					KurooStatusBar::instance()->setProgressStatus( QString(), i18n("Done.") );
+					// added an explicit busy switch to allow someone to continue once
+					// an abort has happened. 20070223 - aga
+					SignalistSingleton::Instance()->setKurooBusy(false);
+					// added a log entry for the abort
+					LogSingleton::Instance()->writeLog( i18n("Emerge aborted by user."), KUROO );
+					SignalistSingleton::Instance()->emergeAborted();
+				default:
+					break;
+			}
+	} else
+		slotButtons();
 }
 
 /**
@@ -558,8 +543,8 @@ void QueueTab::slotAddWorld()
 	const QStringList selectedIdsList = queueView->selectedPackagesByIds();
 
 	QStringList packageList;
-	foreach ( QString id, selectedIdsList )
-		packageList += queueView->packageItemById( id )->category() + "/" + queueView->packageItemById( id )->name();
+	for ( const QString& id : selectedIdsList )
+		packageList += queueView->packageItemById( id )->category() + u'/' + queueView->packageItemById( id )->name();
 	PortageSingleton::Instance()->appendWorld( packageList );
 }
 
@@ -571,8 +556,8 @@ void QueueTab::slotRemoveWorld()
 	const QStringList selectedIdsList = queueView->selectedPackagesByIds();
 
 	QStringList packageList;
-	foreach ( QString id, selectedIdsList )
-		packageList += queueView->packageItemById( id )->category() + "/" + queueView->packageItemById( id )->name();
+	for ( const QString& id : selectedIdsList )
+		packageList += queueView->packageItemById( id )->category() + u'/' + queueView->packageItemById( id )->name();
 	PortageSingleton::Instance()->removeFromWorld( packageList );
 }
 
@@ -601,7 +586,7 @@ void QueueTab::processPackage( bool viewInspector )
 * Popup menu for current package.
 * @param point
 */
-void QueueTab::slotContextMenu(const QPoint &point)
+void QueueTab::slotContextMenu(QPoint point)
 {
 	QModelIndex item = queueView->indexAt(point);
 
@@ -614,13 +599,11 @@ void QueueTab::slotContextMenu(const QPoint &point)
 	menu.addAction( m_packageDetails );
 
 	// Allow editing of World when superuser
-	PackageListItem* internalItem = static_cast<PackageListItem*>( item.internalPointer() );
+	auto* internalItem = static_cast<PackageListItem*>( item.internalPointer() );
 	if ( !internalItem->isInWorld() ) {
 		menu.addAction( m_addToWorld );
-		m_addToWorld->setEnabled( KUser().isSuperUser() );
 	} else {
 		menu.addAction( m_removeFromWorld );
-		m_removeFromWorld->setEnabled( KUser().isSuperUser() );
 	}
 
 	// No change to Queue when busy
